@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FASTFETCH_INCLUDED_FFCHECKMACROS
-#define FASTFETCH_INCLUDED_FFCHECKMACROS
-
 #ifdef _MSC_VER
     #include <sal.h>
 #endif
@@ -26,5 +23,3 @@
 #else
     #define FF_C_SCANF(formatStrIndex, argsStartIndex)
 #endif
-
-#endif
